@@ -31,8 +31,7 @@
 /* xfce includes */
 #include <libxfce4ui/libxfce4ui.h>
 #include <libxfce4util/libxfce4util.h>
-#include <libxfce4panel/xfce-panel-plugin.h>
-#include <libxfce4panel/xfce-panel-convenience.h>
+#include <libxfce4panel/libxfce4panel.h>
 
 #include "datetime.h"
 #include "datetime-dialog.h"
@@ -130,7 +129,15 @@ static gboolean datetime_format_has_seconds(const gchar *format)
 /*
  * set date and time labels
  */
-gboolean datetime_update(t_datetime *datetime)
+static gboolean datetime_update_cb(gpointer user_data)
+{
+  t_datetime *datetime = user_data;
+
+  datetime_update(datetime);
+  return TRUE;
+}
+
+void datetime_update(t_datetime *datetime)
 {
   GTimeVal timeval;
   gchar *utf8str;
@@ -166,13 +173,12 @@ gboolean datetime_update(t_datetime *datetime)
 
   /* Compute the time to the next update and start the timer. */
   wake_interval = datetime_wake_interval(timeval, datetime->update_interval);
-  datetime->timeout_id = g_timeout_add(wake_interval, (GSourceFunc) datetime_update, datetime);
-
-  return TRUE;
+  datetime->timeout_id = g_timeout_add(wake_interval, datetime_update_cb, datetime);
 }
 
-static gboolean datetime_tooltip_timer(t_datetime *datetime)
+static gboolean datetime_tooltip_timer(gpointer user_data)
 {
+  t_datetime *datetime = user_data;
   DBG("wake");
 
   /* flag to datetime_query_tooltip that there is no longer an active timeout */
@@ -232,7 +238,7 @@ static gboolean datetime_query_tooltip(GtkWidget *widget,
      */
     wake_interval = datetime_wake_interval(timeval, 1000);
     datetime->tooltip_timeout_id = g_timeout_add(wake_interval,
-      (GSourceFunc) datetime_tooltip_timer, datetime);
+      datetime_tooltip_timer, datetime);
   }
 
   return TRUE;
@@ -346,7 +352,7 @@ static void datetime_update_date_font(t_datetime *datetime)
   font = pango_font_description_from_string(datetime->date_font);
   if (G_LIKELY (font))
   {
-    css = g_strdup_printf("label { font-family: %s; font-size: %dpx; font-style: %s; font-weight: %s }",
+    css = g_strdup_printf("label { font-family: %s; font-size: %dpt; font-style: %s; font-weight: %s }",
                           pango_font_description_get_family (font),
                           pango_font_description_get_size (font) / PANGO_SCALE,
                           (pango_font_description_get_style(font) == PANGO_STYLE_ITALIC ||
@@ -391,7 +397,7 @@ static void datetime_update_time_font(t_datetime *datetime)
   font = pango_font_description_from_string(datetime->time_font);
   if (G_LIKELY (font))
   {
-    css = g_strdup_printf("label { font-family: %s; font-size: %dpx; font-style: %s; font-weight: %s }",
+    css = g_strdup_printf("label { font-family: %s; font-size: %dpt; font-style: %s; font-weight: %s }",
                           pango_font_description_get_family (font),
                           pango_font_description_get_size (font) / PANGO_SCALE,
                           (pango_font_description_get_style(font) == PANGO_STYLE_ITALIC ||
@@ -679,7 +685,7 @@ static void datetime_create_widget(t_datetime * datetime)
   orientation = xfce_panel_plugin_get_orientation(datetime->plugin);
 
   /* create button */
-  datetime->button = xfce_create_panel_toggle_button();
+  datetime->button = xfce_panel_create_toggle_button();
   gtk_widget_show(datetime->button);
 
   /* create a box which can be easily adapted to the panel orientation */
@@ -718,7 +724,7 @@ static t_datetime * datetime_new(XfcePanelPlugin *plugin)
   DBG("Starting datetime panel plugin");
 
   /* alloc and clear mem */
-  datetime = panel_slice_new0 (t_datetime);
+  datetime = g_slice_new0 (t_datetime);
 
   /* store plugin reference */
   datetime->plugin = plugin;
@@ -755,7 +761,7 @@ static void datetime_free(XfcePanelPlugin *plugin, t_datetime *datetime)
   g_free(datetime->date_format);
   g_free(datetime->time_format);
 
-  panel_slice_free(t_datetime, datetime);
+  g_slice_free(t_datetime, datetime);
 }
 
 /*
